@@ -8,6 +8,7 @@ default_access.enable()
 -- Load devices
 alsa_monitor.enable()
 v4l2_monitor.enable()
+libcamera_monitor.enable()
 
 -- Track/store/restore user choices about devices
 device_defaults.enable()
@@ -20,6 +21,3 @@ load_script("intended-roles.lua")
 
 -- Automatically suspends idle nodes after 3 seconds
 load_script("suspend-node.lua")
-
--- Automatically sets device profiles to 'On'
-load_module("device-activation")
