@@ -49,7 +49,7 @@ function nonempty(str)
   return str ~= "" and str or nil
 end
 
-function createNode(parent, id, type, factory, properties)
+function createNode(parent, id, obj_type, factory, properties)
   local dev_props = parent.properties
 
   -- set the device id and spa factory name; REQUIRED, do not change
@@ -175,6 +175,7 @@ function createNode(parent, id, type, factory, properties)
   -- apply properties from config.rules
   rulesApplyProperties(properties)
   if properties["node.disabled"] then
+    node_names_table [properties ["node.name"]] = nil
     return
   end
 
@@ -190,6 +191,10 @@ function createDevice(parent, id, factory, properties)
     device:connect("create-object", createNode)
     device:connect("object-removed", function (parent, id)
       local node = parent:get_managed_object(id)
+      if not node then
+        return
+      end
+
       node_names_table[node.properties["node.name"]] = nil
     end)
     device:activate(Feature.SpaDevice.ENABLED | Feature.Proxy.BOUND)
@@ -199,7 +204,7 @@ function createDevice(parent, id, factory, properties)
   end
 end
 
-function prepareDevice(parent, id, type, factory, properties)
+function prepareDevice(parent, id, obj_type, factory, properties)
   -- ensure the device has an appropriate name
   local name = "alsa_card." ..
     (properties["device.name"] or
@@ -269,6 +274,7 @@ function prepareDevice(parent, id, type, factory, properties)
   -- apply properties from config.rules
   rulesApplyProperties(properties)
   if properties["device.disabled"] then
+    device_names_table [properties ["device.name"]] = nil
     return
   end
 
@@ -346,6 +352,10 @@ function createMonitor ()
   -- handle object-removed to destroy device reservations and recycle device name
   m:connect("object-removed", function (parent, id)
     local device = parent:get_managed_object(id)
+    if not device then
+      return
+    end
+
     if rd_plugin then
       local rd_name = device.properties["api.dbus.ReserveDevice1"]
       if rd_name then
@@ -385,7 +395,7 @@ end
 -- if the reserve-device plugin is enabled, at the point of script execution
 -- it is expected to be connected. if it is not, assume the d-bus connection
 -- has failed and continue without it
-if rd_plugin and rd_plugin["state"] ~= "connected" then
+if rd_plugin and rd_plugin:call("get-dbus")["state"] ~= "connected" then
   Log.message("reserve-device plugin is not connected to D-Bus, "
               .. "disabling device reservation")
   rd_plugin = nil
