@@ -240,11 +240,29 @@ l_test_object_new (lua_State * L)
   return 1;
 }
 
+static gboolean
+test_load_and_call (lua_State * L, const gchar *buf, gsize size,
+    int nargs, int nres, GError **error)
+{
+  int argstop = lua_gettop (L);
+  int sandbox = wplua_push_sandbox (L);
+
+  if (!wplua_load_buffer (L, buf, size, error)) {
+    lua_pop (L, nargs + sandbox);
+    return FALSE;
+  }
+
+  /* push sandbox() and the chunk below the arguments */
+  lua_rotate (L, argstop, -nargs);
+
+  return wplua_pcall (L, nargs + sandbox, nres, error);
+}
+
 static void
 test_wplua_basic ()
 {
   lua_State *L = wplua_new ();
-  wplua_free (L);
+  wplua_unref (L);
 }
 
 static void
@@ -260,7 +278,7 @@ test_wplua_construct ()
   const gchar code[] =
     "o = TestObject_new()\n"
     "assert (type(o) == 'userdata')\n";
-  wplua_load_buffer (L, code, sizeof (code) - 1, 0, 0, &error);
+  test_load_and_call (L, code, sizeof (code) - 1, 0, 0, &error);
   g_assert_no_error (error);
 
   g_assert_cmpint (lua_getglobal (L, "o"), ==, LUA_TUSERDATA);
@@ -270,7 +288,7 @@ test_wplua_construct ()
   g_object_ref (obj);
   g_assert_cmpint (obj->ref_count, ==, 2);
 
-  wplua_free (L);
+  wplua_unref (L);
   g_assert_cmpint (obj->ref_count, ==, 1);
 }
 
@@ -294,7 +312,7 @@ test_wplua_properties ()
     "o['test-float'] = 3.1415\n"
     "o['test-double'] = 0.123456789\n"
     "o['test-boolean'] = true\n";
-  wplua_load_buffer (L, code, sizeof (code) - 1, 0, 0, &error);
+  test_load_and_call (L, code, sizeof (code) - 1, 0, 0, &error);
   g_assert_no_error (error);
 
   g_assert_cmpint (lua_getglobal (L, "o"), ==, LUA_TUSERDATA);
@@ -320,10 +338,10 @@ test_wplua_properties ()
     "assert (math.abs (o['test-float'] - 3.1415) < 0.00001)\n"
     "assert (math.abs (o['test-double'] - 0.123456789) < 0.0000000001)\n"
     "assert (o['test-boolean'] == true)\n";
-  wplua_load_buffer (L, code2, sizeof (code2) - 1, 0, 0, &error);
+  test_load_and_call (L, code2, sizeof (code2) - 1, 0, 0, &error);
   g_assert_no_error (error);
 
-  wplua_free (L);
+  wplua_unref (L);
 }
 
 static void
@@ -342,7 +360,7 @@ test_wplua_closure ()
     "  assert(s == expected_str)\n"
     "  f_was_called = true\n"
     "end\n";
-  wplua_load_buffer (L, code, sizeof (code) - 1, 0, 0, &error);
+  test_load_and_call (L, code, sizeof (code) - 1, 0, 0, &error);
   g_assert_no_error (error);
 
   lua_getglobal (L, "f");
@@ -363,7 +381,7 @@ test_wplua_closure ()
   g_assert_true (lua_isboolean (L, -1));
   g_assert_true (lua_toboolean (L, -1));
 
-  wplua_free (L);
+  wplua_unref (L);
 
   g_assert_true (closure->is_invalid);
   g_closure_unref (closure);
@@ -400,9 +418,9 @@ test_wplua_signals ()
     "o['test-boolean'] = true\n"
     "o:toggle()\n"
     "assert(o['test-boolean'] == false)\n";
-  wplua_load_buffer (L, code, sizeof (code) - 1, 0, 0, &error);
+  test_load_and_call (L, code, sizeof (code) - 1, 0, 0, &error);
   g_assert_no_error (error);
-  wplua_free (L);
+  wplua_unref (L);
 }
 
 static void
@@ -419,14 +437,14 @@ test_wplua_sandbox_script ()
     "  Test = TestObject_new,\n"
     "  Table = { test = 'foobar' }\n"
     "}\n";
-  wplua_load_buffer (L, code, sizeof (code) - 1, 0, 0, &error);
+  test_load_and_call (L, code, sizeof (code) - 1, 0, 0, &error);
   g_assert_no_error (error);
 
   wplua_enable_sandbox (L, WP_LUA_SANDBOX_ISOLATE_ENV);
 
   const gchar code2[] =
     "o = TestObject_new()\n";
-  wplua_load_buffer (L, code2, sizeof (code2) - 1, 0, 0, &error);
+  test_load_and_call (L, code2, sizeof (code2) - 1, 0, 0, &error);
   g_debug ("expected error: %s", error ? error->message : "null");
   g_assert_error (error, WP_DOMAIN_LUA, WP_LUA_ERROR_RUNTIME);
   g_clear_error (&error);
@@ -434,36 +452,36 @@ test_wplua_sandbox_script ()
   const gchar code3[] =
     "o = Test()\n"
     "o:toggle()\n";
-  wplua_load_buffer (L, code3, sizeof (code3) - 1, 0, 0, &error);
+  test_load_and_call (L, code3, sizeof (code3) - 1, 0, 0, &error);
   g_assert_no_error (error);
 
   const gchar code4[] =
     "assert(string.len(Table.test) == 6)\n";
-  wplua_load_buffer (L, code4, sizeof (code4) - 1, 0, 0, &error);
+  test_load_and_call (L, code4, sizeof (code4) - 1, 0, 0, &error);
   g_assert_no_error (error);
 
   const gchar code5[] =
     "o:call('change', 'by Lua', 55)\n";
-  wplua_load_buffer (L, code5, sizeof (code5) - 1, 0, 0, &error);
+  test_load_and_call (L, code5, sizeof (code5) - 1, 0, 0, &error);
   g_debug ("expected error: %s", error ? error->message : "null");
   g_assert_error (error, WP_DOMAIN_LUA, WP_LUA_ERROR_RUNTIME);
   g_clear_error (&error);
 
   const gchar code6[] =
     "string.test = 'hello world'\n";
-  wplua_load_buffer (L, code6, sizeof (code6) - 1, 0, 0, &error);
+  test_load_and_call (L, code6, sizeof (code6) - 1, 0, 0, &error);
   g_debug ("expected error: %s", error ? error->message : "null");
   g_assert_error (error, WP_DOMAIN_LUA, WP_LUA_ERROR_RUNTIME);
   g_clear_error (&error);
 
   const gchar code7[] =
     "Table.test = 'hello world'\n";
-  wplua_load_buffer (L, code7, sizeof (code7) - 1, 0, 0, &error);
+  test_load_and_call (L, code7, sizeof (code7) - 1, 0, 0, &error);
   g_debug ("expected error: %s", error ? error->message : "null");
   g_assert_error (error, WP_DOMAIN_LUA, WP_LUA_ERROR_RUNTIME);
   g_clear_error (&error);
 
-  wplua_free (L);
+  wplua_unref (L);
 }
 
 static void
@@ -472,11 +490,11 @@ test_wplua_sandbox_config ()
   g_autoptr (GError) error = NULL;
   lua_State *L = wplua_new ();
 
-  wplua_enable_sandbox (L, WP_LUA_SANDBOX_MINIMAL_STD);
+  wplua_enable_sandbox (L, 0);
 
   const gchar code3[] =
     "o = { answer = 42 }\n";
-  wplua_load_buffer (L, code3, sizeof (code3) - 1, 0, 0, &error);
+  test_load_and_call (L, code3, sizeof (code3) - 1, 0, 0, &error);
   g_assert_no_error (error);
 
   /* no assert() in minimal_std mode, resort to other means of failure */
@@ -484,13 +502,13 @@ test_wplua_sandbox_config ()
     "if (o.answer ~= 42) then\n"
     "  non_existent_function()\n"
     "end\n";
-  wplua_load_buffer (L, code4, sizeof (code4) - 1, 0, 0, &error);
+  test_load_and_call (L, code4, sizeof (code4) - 1, 0, 0, &error);
   g_assert_no_error (error);
 
   /* string.* is protected */
   const gchar code6[] =
     "string.test = 'hello world'\n";
-  wplua_load_buffer (L, code6, sizeof (code6) - 1, 0, 0, &error);
+  test_load_and_call (L, code6, sizeof (code6) - 1, 0, 0, &error);
   g_debug ("expected error: %s", error ? error->message : "null");
   g_assert_error (error, WP_DOMAIN_LUA, WP_LUA_ERROR_RUNTIME);
   g_clear_error (&error);
@@ -498,10 +516,10 @@ test_wplua_sandbox_config ()
   /* this would be an error if the assert function was exported, but it's not */
   const gchar code7[] =
     "assert = 'hello world'\n";
-  wplua_load_buffer (L, code7, sizeof (code7) - 1, 0, 0, &error);
+  test_load_and_call (L, code7, sizeof (code7) - 1, 0, 0, &error);
   g_assert_no_error (error);
 
-  wplua_free (L);
+  wplua_unref (L);
 }
 
 static void
@@ -526,7 +544,7 @@ test_wplua_convert_asv ()
     "assert (math.abs (o['test-double'] - 3.14) < 0.0000000001)\n"
     "assert (o['test-boolean'] == true)\n"
     "assert (o['nested-table']['string'] == 'baz')\n";
-  wplua_load_buffer (L, code2, sizeof (code2) - 1, 0, 0, &error);
+  test_load_and_call (L, code2, sizeof (code2) - 1, 0, 0, &error);
   g_assert_no_error (error);
 
   lua_getglobal (L, "o");
@@ -557,7 +575,7 @@ test_wplua_convert_asv ()
   g_assert_true (g_variant_lookup (nested, "string", "&s", &test_str));
   g_assert_cmpstr (test_str, ==, "baz");
 
-  wplua_free (L);
+  wplua_unref (L);
 }
 
 static void
@@ -578,7 +596,7 @@ test_wplua_convert_gvariant_array ()
     "assert (o[3] == 'foobar')\n"
     "assert (o[4] == true)\n"
     "assert (o[5]['string'] == 'baz')\n";
-  wplua_load_buffer (L, code2, sizeof (code2) - 1, 0, 0, &error);
+  test_load_and_call (L, code2, sizeof (code2) - 1, 0, 0, &error);
   g_assert_no_error (error);
 
   lua_getglobal (L, "o");
@@ -609,7 +627,7 @@ test_wplua_convert_gvariant_array ()
   g_assert_true (g_variant_lookup (nested, "string", "&s", &test_str));
   g_assert_cmpstr (test_str, ==, "baz");
 
-  wplua_free (L);
+  wplua_unref (L);
 }
 static void
 test_wplua_convert_wp_properties ()
@@ -624,7 +642,7 @@ test_wplua_convert_wp_properties ()
     "  ['test-string'] = 'foobar', "
     "  ['test-boolean'] = false, "
     "}\n";
-  wplua_load_buffer (L, code, sizeof (code) - 1, 0, 0, &error);
+  test_load_and_call (L, code, sizeof (code) - 1, 0, 0, &error);
   g_assert_no_error (error);
 
   lua_getglobal (L, "props");
@@ -644,10 +662,10 @@ test_wplua_convert_wp_properties ()
     "assert (fromc['test-int'] == '42')\n"
     "assert (fromc['test-double'] == '3.14')\n"
     "assert (fromc['test-boolean'] == 'false')\n";
-  wplua_load_buffer (L, code2, sizeof (code2) - 1, 0, 0, &error);
+  test_load_and_call (L, code2, sizeof (code2) - 1, 0, 0, &error);
   g_assert_no_error (error);
 
-  wplua_free (L);
+  wplua_unref (L);
 }
 
 static void
@@ -672,16 +690,16 @@ test_wplua_script_arguments ()
     "assert (math.abs (o['test-double'] - 3.14) < 0.0000000001)\n"
     "assert (o['test-boolean'] == true)\n"
     "assert (o['nested-table']['string'] == 'baz')\n";
-  wplua_load_buffer (L, code2, sizeof (code2) - 1, 1, 0, &error);
+  test_load_and_call (L, code2, sizeof (code2) - 1, 1, 0, &error);
   g_assert_no_error (error);
 
   /* same test, but with sandbox enabled */
   wplua_enable_sandbox (L, WP_LUA_SANDBOX_ISOLATE_ENV);
   wplua_gvariant_to_lua (L, v);
-  wplua_load_buffer (L, code2, sizeof (code2) - 1, 1, 0, &error);
+  test_load_and_call (L, code2, sizeof (code2) - 1, 1, 0, &error);
   g_assert_no_error (error);
 
-  wplua_free (L);
+  wplua_unref (L);
 }
 
 gint
